Functions reference
===================

Functions in T\ :sub:`c`\ 1D
----------------------------

``calculate_misfit``
~~~~~~~~~~~~~~~~~~~~

.. autofunction:: tc1d.calculate_misfit

``calculate_erosion_rate``
~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autofunction:: tc1d.calculate_erosion_rate

``init_params``
~~~~~~~~~~~~~~~

.. autofunction:: tc1d.init_params
